@@ -43,17 +43,10 @@ def post_generate(conanfile):
     ConanOutput().success(f"CYCLONEDX CREATED - {{conanfile.generators_folder}}")
 """
 
+
 @pytest.mark.parametrize("cyclone_version", ["cyclonedx_1_4", "cyclonedx_1_6"])
 class TestCyclonedx:
 
-    @pytest.fixture()
-    def hook_setup_post_package_default(self, cyclone_version):
-        tc = TestClient()
-        hook_path = os.path.join(tc.paths.hooks_path, "hook_sbom.py")
-        save(hook_path, sbom_hook_post_package.format(cyclone_version=cyclone_version,
-                                                      add_build=False, add_tests=False))
-        return tc
-
     @pytest.fixture()
     def hook_setup_post_package(self, cyclone_version):
         tc = TestClient()
@@ -385,3 +378,15 @@ class TestCyclonedx:
 
         assert content_json["components"][0]["bom-ref"].split("&user=")[1] == f"{user}&channel={channel}" if channel else user
         assert content_json["dependencies"][0]["dependsOn"][0].split("&user=")[1] == f"{user_dep}&channel={channel_dep}" if channel_dep else user_dep
+
+    def test_sbom_test_requires_skipped(self, cyclone_version):
+        tc = TestClient()
+        hook_path = os.path.join(tc.paths.hooks_path, "hook_sbom.py")
+        save(hook_path, sbom_hook_post_generate.format(cyclone_version=cyclone_version, name=None,
+                                                       add_build=False, add_tests=False))
+        tc.save({"dep/conanfile.py": GenConanfile("mydep", "1.0"),
+                 "conanfile.py": GenConanfile("foo", "1.0").with_test_requires("mydep/1.0")})
+        tc.run("create dep")
+        tc.run("install .")
+        content = tc.load("sbom/sbom.cdx.json")
+        assert "mydep" not in content
