@@ -2,16 +2,13 @@ import os
 import platform
 import textwrap
 import time
-import unittest
 
 import pytest
-from parameterized.parameterized import parameterized
 
 from conan.test.assets.cmake import gen_cmakelists
 from conan.test.assets.sources import gen_function_cpp, gen_function_h
 from test.functional.utils import check_vs_runtime, check_exe_run
 from conan.test.utils.tools import TestClient
-from conan.internal.util.files import save
 
 
 @pytest.mark.tool("cmake", "3.15")
@@ -45,7 +42,7 @@ def test_simple_cmake_mingw():
 
 
 @pytest.mark.tool("cmake")
-class Base(unittest.TestCase):
+class Base:
 
     conanfile = textwrap.dedent(r"""
         from conan import ConanFile
@@ -127,7 +124,8 @@ class Base(unittest.TestCase):
         target_link_libraries(app PRIVATE app_lib)
         """)
 
-    def setUp(self):
+    @pytest.fixture(autouse=True)
+    def setup(self):
         self.client = TestClient()
         conanfile = textwrap.dedent("""
             from conan import ConanFile
@@ -192,22 +190,23 @@ class Base(unittest.TestCase):
             if platform.system() == "Windows":
                 command_str = command_str.replace("/", "\\")
         self.client.run_command(command_str)
-        self.assertIn("Hello: %s" % build_type, self.client.out)
-        self.assertIn("%s: %s!" % (msg, build_type), self.client.out)
-        self.assertIn("MYVAR: MYVAR_VALUE", self.client.out)
-        self.assertIn("MYVAR_CONFIG: MYVAR_%s" % build_type.upper(), self.client.out)
-        self.assertIn("MYDEFINE: MYDEF_VALUE", self.client.out)
-        self.assertIn("MYDEFINE_CONFIG: MYDEF_%s" % build_type.upper(), self.client.out)
-        self.assertIn("MYDEFINEINT: 42", self.client.out)
-        self.assertIn("MYDEFINEINT_CONFIG: {}".format(421 if build_type == "Debug" else 422),
-                      self.client.out)
+        assert "Hello: %s" % build_type in self.client.out
+        assert "%s: %s!" % (msg, build_type) in self.client.out
+        assert "MYVAR: MYVAR_VALUE" in self.client.out
+        assert "MYVAR_CONFIG: MYVAR_%s" % build_type.upper() in self.client.out
+        assert "MYDEFINE: MYDEF_VALUE" in self.client.out
+        assert "MYDEFINE_CONFIG: MYDEF_%s" % build_type.upper() in self.client.out
+        assert "MYDEFINEINT: 42" in self.client.out
+        value = 421 if build_type == "Debug" else 422
+        assert f"MYDEFINEINT_CONFIG: {value}" in self.client.out
 
 
 @pytest.mark.skipif(platform.system() != "Windows", reason="Only for windows")
-class WinTest(Base):
-    @parameterized.expand([("msvc", "Debug", "static", "191", "14", "x86", True),
-                           ("msvc", "Release", "dynamic", "191", "17", "x86_64", False)]
-                          )
+class TestWin(Base):
+    @pytest.mark.parametrize("compiler, build_type, runtime, version, cppstd, arch, shared",
+                             [("msvc", "Debug", "static", "191", "14", "x86", True),
+                              ("msvc", "Release", "dynamic", "191", "17", "x86_64", False)]
+                             )
     def test_toolchain_win(self, compiler, build_type, runtime, version, cppstd, arch, shared):
         settings = {"compiler": compiler,
                     "compiler.version": version,
@@ -217,10 +216,10 @@ class WinTest(Base):
                     "build_type": build_type,
                     }
         options = {"shared": shared}
-        save(self.client.paths.new_config_path, "tools.build:jobs=1")
+        self.client.save_home({"global.conf": "tools.build:jobs=1"})
         self._run_build(settings, options)
-        self.assertIn('cmake -G "Visual Studio 15 2017" '
-                      '-DCMAKE_TOOLCHAIN_FILE="conan_toolchain.cmake"', self.client.out)
+        assert ('cmake -G "Visual Studio 15 2017" '
+                '-DCMAKE_TOOLCHAIN_FILE="conan_toolchain.cmake"') in self.client.out
 
         generator_platform = "x64" if arch == "x86_64" else "Win32"
         arch_flag = "x64" if arch == "x86_64" else "X86"
@@ -241,13 +240,13 @@ class WinTest(Base):
 
         def _verify_out(marker=">>"):
             if shared:
-                self.assertIn("app_lib.dll", self.client.out)
+                assert "app_lib.dll" in self.client.out
             else:
-                self.assertNotIn("app_lib.dll", self.client.out)
+                assert "app_lib.dll" not in self.client.out
 
             out = str(self.client.out).splitlines()
             for k, v in vals.items():
-                self.assertIn("%s %s: %s" % (marker, k, v), out)
+                assert "%s %s: %s" % (marker, k, v) in out
 
         _verify_out()
 
@@ -284,8 +283,9 @@ class WinTest(Base):
         self._incremental_build(build_type=opposite_build_type)
         self._run_app(opposite_build_type, bin_folder=True, msg="AppImproved")
 
-    @parameterized.expand([("Debug", "libstdc++", "4.9", "98", "x86_64", True),
-                           ("Release", "libstdc++", "4.9", "11", "x86_64", False)])
+    @pytest.mark.parametrize("build_type, libcxx, version, cppstd, arch, shared",
+                             [("Debug", "libstdc++", "4.9", "98", "x86_64", True),
+                              ("Release", "libstdc++", "4.9", "11", "x86_64", False)])
     @pytest.mark.tool("mingw64")
     @pytest.mark.tool("cmake", "3.15")
     def test_toolchain_mingw_win(self, build_type, libcxx, version, cppstd, arch, shared):
@@ -299,9 +299,9 @@ class WinTest(Base):
                     }
         options = {"shared": shared}
         self._run_build(settings, options)
-        self.assertIn("The C compiler identification is GNU", self.client.out)
-        self.assertIn('cmake -G "MinGW Makefiles" '
-                      '-DCMAKE_TOOLCHAIN_FILE="conan_toolchain.cmake"', self.client.out)
+        assert "The C compiler identification is GNU" in self.client.out
+        assert ('cmake -G "MinGW Makefiles" '
+                '-DCMAKE_TOOLCHAIN_FILE="conan_toolchain.cmake"') in self.client.out
         assert '-DCMAKE_SH="CMAKE_SH-NOTFOUND"' in self.client.out
 
         def _verify_out(marker=">>"):
@@ -319,13 +319,13 @@ class WinTest(Base):
                           "CMAKE_CXX_EXTENSIONS": "OFF",
                           "BUILD_SHARED_LIBS": "ON" if shared else "OFF"}
             if shared:
-                self.assertIn("app_lib.dll", self.client.out)
+                assert "app_lib.dll" in self.client.out
             else:
-                self.assertNotIn("app_lib.dll", self.client.out)
+                assert "app_lib.dll" not in self.client.out
 
             out = str(self.client.out).splitlines()
             for k, v in cmake_vars.items():
-                self.assertIn("%s %s: %s" % (marker, k, v), out)
+                assert "%s %s: %s" % (marker, k, v) in out
 
         _verify_out()
         self._run_app(build_type)
@@ -344,9 +344,10 @@ class WinTest(Base):
 
 
 @pytest.mark.skipif(platform.system() != "Linux", reason="Only for Linux")
-class LinuxTest(Base):
-    @parameterized.expand([("Debug",  "14", "x86", "libstdc++", True),
-                           ("Release", "gnu14", "x86_64", "libstdc++11", False)])
+class TestLinux(Base):
+    @pytest.mark.parametrize("build_type, cppstd, arch, libcxx, shared",
+                             [("Debug",  "14", "x86", "libstdc++", True),
+                              ("Release", "gnu14", "x86_64", "libstdc++11", False)])
     def test_toolchain_linux(self, build_type, cppstd, arch, libcxx, shared):
         settings = {"compiler": "gcc",
                     "compiler.cppstd": cppstd,
@@ -354,8 +355,8 @@ class LinuxTest(Base):
                     "arch": arch,
                     "build_type": build_type}
         self._run_build(settings, {"shared": shared})
-        self.assertIn('cmake -G "Unix Makefiles" '
-                      '-DCMAKE_TOOLCHAIN_FILE="conan_toolchain.cmake"', self.client.out)
+        assert ('cmake -G "Unix Makefiles" '
+                '-DCMAKE_TOOLCHAIN_FILE="conan_toolchain.cmake"') in self.client.out
 
         extensions_str = "ON" if "gnu" in cppstd else "OFF"
         arch_str = "-m32" if arch == "x86" else "-m64"
@@ -384,13 +385,13 @@ class LinuxTest(Base):
 
         def _verify_out(marker=">>"):
             if shared:
-                self.assertIn("libapp_lib.so", self.client.out)
+                assert "libapp_lib.so" in self.client.out
             else:
-                self.assertIn("libapp_lib.a", self.client.out)
+                assert "libapp_lib.a" in self.client.out
 
             out = str(self.client.out).splitlines()
             for k, v in vals.items():
-                self.assertIn("%s %s: %s" % (marker, k, v), out)
+                assert "%s %s: %s" % (marker, k, v) in out
 
         _verify_out()
 
@@ -403,17 +404,18 @@ class LinuxTest(Base):
 
 
 @pytest.mark.skipif(platform.system() != "Darwin", reason="Only for Apple")
-class AppleTest(Base):
-    @parameterized.expand([("Debug",  "14",  True),
-                           ("Release", "", False)])
+class TestApple(Base):
+    @pytest.mark.parametrize("build_type, cppstd, shared",
+                             [("Debug",  "14",  True),
+                              ("Release", "", False)])
     def test_toolchain_apple(self, build_type, cppstd, shared):
         settings = {"compiler": "apple-clang",
                     "compiler.cppstd": cppstd,
                     "build_type": build_type}
         self._run_build(settings, {"shared": shared})
 
-        self.assertIn('cmake -G "Unix Makefiles" '
-                      '-DCMAKE_TOOLCHAIN_FILE="conan_toolchain.cmake"', self.client.out)
+        assert ('cmake -G "Unix Makefiles" '
+                '-DCMAKE_TOOLCHAIN_FILE="conan_toolchain.cmake"') in self.client.out
 
         extensions_str = "OFF" if cppstd else ""
         vals = {"CMAKE_CXX_STANDARD": cppstd,
@@ -441,15 +443,15 @@ class AppleTest(Base):
 
         def _verify_out(marker=">>"):
             if shared:
-                self.assertIn("libapp_lib.dylib", self.client.out)
+                assert "libapp_lib.dylib" in self.client.out
             else:
                 if marker == ">>":
-                    self.assertIn("libapp_lib.a", self.client.out)
+                    assert "libapp_lib.a" in self.client.out
                 else:  # Incremental build not the same msg
-                    self.assertIn("Built target app_lib", self.client.out)
+                    assert "Built target app_lib" in self.client.out
             out = str(self.client.out).splitlines()
             for k, v in vals.items():
-                self.assertIn("%s %s: %s" % (marker, k, v), out)
+                assert "%s %s: %s" % (marker, k, v) in out
 
         _verify_out()
 
@@ -472,7 +474,7 @@ def test_msvc_vs_versiontoolset():
                 "build_type": "Release",
                 }
     client = TestClient()
-    save(client.paths.new_config_path, "tools.microsoft.msbuild:vs_version=15")
+    client.save_home({"global.conf": "tools.microsoft.msbuild:vs_version=15"})
     conanfile = textwrap.dedent("""
             from conan import ConanFile
             from conan.tools.cmake import CMake
@@ -504,7 +506,7 @@ def test_msvc_vs_versiontoolset():
 
 
 @pytest.mark.tool("cmake")
-class CMakeInstallTest(unittest.TestCase):
+class TestCMakeInstall:
 
     def test_install(self):
         conanfile = textwrap.dedent("""
@@ -535,13 +537,14 @@ class CMakeInstallTest(unittest.TestCase):
                      "header.h": "# my header file"})
 
         # The create flow must work
-        client.run("create . --name=pkg --version=0.1 -c tools.build:verbosity=verbose -c tools.compilation:verbosity=verbose")
+        client.run("create . --name=pkg --version=0.1 -c tools.build:verbosity=verbose "
+                   "-c tools.compilation:verbosity=verbose")
         assert "--loglevel=VERBOSE" in client.out
         assert "unrecognized option" not in client.out
         assert "--verbose" in client.out
-        self.assertIn("pkg/0.1: package(): Packaged 1 '.h' file: header.h", client.out)
+        assert "pkg/0.1: package(): Packaged 1 '.h' file: header.h" in client.out
         package_folder = client.created_layout().package()
-        self.assertTrue(os.path.exists(os.path.join(package_folder, "include", "header.h")))
+        assert os.path.exists(os.path.join(package_folder, "include", "header.h"))
 
     def test_install_in_build(self):
         """
@@ -630,7 +633,7 @@ class TestCmakeTestMethod:
 
 
 @pytest.mark.tool("cmake")
-class CMakeOverrideCacheTest(unittest.TestCase):
+class TestCMakeOverrideCache:
 
     def test_cmake_cache_variables(self):
         # https://github.com/conan-io/conan/issues/7832
@@ -659,7 +662,7 @@ class CMakeOverrideCacheTest(unittest.TestCase):
         client.save({"conanfile.py": conanfile,
                      "CMakeLists.txt": cmakelist})
         client.run("build .")
-        self.assertIn("VALUE OF CONFIG STRING: my new value", client.out)
+        assert "VALUE OF CONFIG STRING: my new value" in client.out
 
 
 @pytest.mark.tool("cmake")
