@@ -111,7 +111,7 @@ class TestConanfilePath:
         client = TestClient()
 
         client.run("graph info", assert_error=True)
-        assert "ERROR: Please specify a path" in client.out
+        assert "ERROR: Conanfile not found" in client.out
 
         client.run("graph info not_real_path", assert_error=True)
         assert "ERROR: Conanfile not found" in client.out
@@ -119,6 +119,12 @@ class TestConanfilePath:
         client.run("graph info conanfile.txt", assert_error=True)
         assert "ERROR: Conanfile not found" in client.out
 
+        client.run("graph info --requires=foo/1.0", assert_error=True)
+        assert "ERROR: Package 'foo/1.0' not resolved: No remote defined." in client.out
+
+        client.run("graph info . --requires=foo/1.0", assert_error=True)
+        assert "--requires and --tool-requires arguments are incompatible with [path] '.' argument" in client.out
+
 
 class TestFilters:
 
@@ -158,16 +164,37 @@ class TestFilters:
 
 class TestJsonOutput:
     def test_json_package_filter(self):
-        # Formatted output like json or html doesn't make sense to be filtered
         client = TestClient()
-        conanfile = GenConanfile("pkg", "0.1").with_setting("build_type")
-        client.save({"conanfile.py": conanfile})
+        conanfile = GenConanfile("pkg", "0.1").with_setting("build_type").with_requires("dep/0.1")
+        client.save({"dep/conanfile.py": GenConanfile("dep", "0.1"),
+                     "conanfile.py": conanfile})
+        client.run("create dep")
         client.run("graph info . --package-filter=nothing --format=json")
         assert '"nodes": {}' in client.out
         client.run("graph info . --package-filter=pkg* --format=json")
         graph = json.loads(client.stdout)
+        assert len(graph["graph"]["nodes"]) == 1
         assert graph["graph"]["nodes"]["0"]["ref"] == "pkg/0.1"
 
+        # Consumer & filtering
+        client.run("graph info . --package-filter=& --format=json")
+        graph = json.loads(client.stdout)
+        assert len(graph["graph"]["nodes"]) == 1
+        assert graph["graph"]["nodes"]["0"]["ref"] == "pkg/0.1"
+
+        # This returns nothing, doesn't work that way, serialized graph doesn't have the consumer
+        client.run("graph info --requires=dep/0.1 --package-filter=& --format=json")
+        graph = json.loads(client.stdout)
+        assert len(graph["graph"]["nodes"]) == 1
+        assert graph["graph"]["nodes"]["1"]["name"] == "dep"
+
+        # Filter matches all
+        client.run("graph info . --package-filter=* --format=json")
+        graph = json.loads(client.stdout)
+        assert len(graph["graph"]["nodes"]) == 2
+        assert graph["graph"]["nodes"]["0"]["ref"] == "pkg/0.1"
+        assert graph["graph"]["nodes"]["1"]["name"] == "dep"
+
     def test_json_info_outputs(self):
         client = TestClient()
         conanfile = GenConanfile("pkg", "0.1").with_setting("build_type")
