@@ -273,11 +273,12 @@ class TestPkgListMerge:
         c.run("create . --version=1.0 --format=json", redirect_stdout="out/graph.json")
         c.run("pkglist merge -l out/graph.json", assert_error=True)
         assert (
-            'ERROR: Expected a package list file but found a graph file. You can create a "package list" JSON file by running:'
-            in c.out
+            'ERROR: Expected a package list file but found a graph file. '
+            'You can create a "package list" JSON file by running:' in c.out
         )
         assert "conan list --graph graph.json --format=json > pkglist.json" in c.out
 
+
 class TestDownloadUpload:
     @pytest.fixture()
     def client(self):
@@ -312,6 +313,21 @@ class TestDownloadUpload:
         assert "Uploading package 'zlib/1.0.0" in client.out
         assert "Uploading package 'zli/" not in client.out
 
+    def test_download_upload_all_no_removed(self):
+        c = TestClient(default_server_user=True, light=True)
+        c.save({"zlib.py": GenConanfile("zlib", "0.1")})
+        c.run("create zlib.py ")
+        c.run("upload * -r=default -c --format=json", redirect_stdout="pkglist.json")
+        c.run("remove * -c")
+        c.run(f"download --list=pkglist.json -r=default --format=json",
+              redirect_stdout="pkglist.json")
+        # The original "files" and "upload-urls" fields of first upload are removed
+        pkglist_json = c.load("pkglist.json")
+        assert "files" not in pkglist_json
+        assert "upload-urls" not in pkglist_json
+        c.run("upload --list=pkglist.json -r=default --format=json")
+        # It doesn't crash anymore
+
     @pytest.mark.parametrize("prev_list", [False, True])
     def test_download_upload_only_recipes(self, client, prev_list):
         if prev_list:
@@ -351,19 +367,29 @@ class TestListRemove:
     def test_remove_nothing_only_refs(self, client):
         # It is necessary to do *#* for actually removing something
         client.run(f"list * --format=json", redirect_stdout="pkglist.json")
-        client.run(f"remove --list=pkglist.json -c")
+        client.run(f"remove --list=pkglist.json -c --format=json")
         assert "Nothing to remove, package list do not contain recipe revisions" in client.out
+        result = json.loads(client.stdout)
+        assert result["Local Cache"] == {}  # Nothing was removed
 
     @pytest.mark.parametrize("remote", [False, True])
     def test_remove_all(self, client, remote):
         # It is necessary to do *#* for actually removing something
         remote = "-r=default" if remote else ""
         client.run(f"list *#* {remote} --format=json", redirect_stdout="pkglist.json")
-        client.run(f"remove --list=pkglist.json {remote} -c")
+        client.run(f"remove --list=pkglist.json {remote} -c --dry-run")
         assert "zli/1.0.0#f034dc90894493961d92dd32a9ee3b78:" \
                " Removed recipe and all binaries" in client.out
         assert "zlib/1.0.0@user/channel#ffd4bc45820ddb320ab224685b9ba3fb:" \
                " Removed recipe and all binaries" in client.out
+
+        client.run(f"remove --list=pkglist.json {remote} -c --format=json")
+        result = json.loads(client.stdout)
+        origin = "Local Cache" if not remote else "default"
+        assert len(result[origin]["zli/1.0.0"]["revisions"]) == 1
+        assert len(result[origin]["zlib/1.0.0@user/channel"]["revisions"]) == 1
+        assert "packages" not in client.stdout  # Packages are not listed at all
+
         client.run(f"list * {remote}")
         assert "There are no matching recipe references" in client.out
 
@@ -372,22 +398,35 @@ class TestListRemove:
         # It is necessary to do *#* for actually removing something
         remote = "-r=default" if remote else ""
         client.run(f"list *#*:* {remote} --format=json", redirect_stdout="pkglist.json")
-        client.run(f"remove --list=pkglist.json {remote} -c")
+        client.run(f"remove --list=pkglist.json {remote} -c --format=json")
         assert "No binaries to remove for 'zli/1.0.0#f034dc90894493961d92dd32a9ee3b78'" in client.out
         assert "No binaries to remove for 'zlib/1.0.0@user/channel" \
                "#ffd4bc45820ddb320ab224685b9ba3fb" in client.out
+        result = json.loads(client.stdout)
+        origin = "Local Cache" if not remote else "default"
+        assert result[origin] == {}  # Nothing was removed
 
     @pytest.mark.parametrize("remote", [False, True])
     def test_remove_packages(self, client, remote):
         # It is necessary to do *#* for actually removing something
         remote = "-r=default" if remote else ""
         client.run(f"list *#*:*#* {remote} --format=json", redirect_stdout="pkglist.json")
-        client.run(f"remove --list=pkglist.json {remote} -c")
-
+        client.run(f"remove --list=pkglist.json {remote} -c --dry-run")
         assert "Removed recipe and all binaries" not in client.out
         assert "zli/1.0.0#f034dc90894493961d92dd32a9ee3b78: Removed binaries" in client.out
         assert "zlib/1.0.0@user/channel#ffd4bc45820ddb320ab224685b9ba3fb: " \
                "Removed binaries" in client.out
+
+        client.run(f"remove --list=pkglist.json {remote} -c --format=json")
+        result = json.loads(client.stdout)
+        origin = "Local Cache" if not remote else "default"
+        zli_revs = result[origin]["zli/1.0.0"]["revisions"]
+        zli_uc_revs = result[origin]["zlib/1.0.0@user/channel"]["revisions"]
+        assert len(zli_revs) == 1
+        assert len(zli_uc_revs) == 1
+        assert len(zli_revs["f034dc90894493961d92dd32a9ee3b78"]["packages"]) == 1
+        assert len(zli_uc_revs["ffd4bc45820ddb320ab224685b9ba3fb"]["packages"]) == 1
+
         client.run(f"list *:* {remote}")
         assert "zli/1.0.0" in client.out
         assert "zlib/1.0.0@user/channel" in client.out
@@ -442,7 +481,8 @@ class TestListGraphContext:
         tc = TestClient(light=True)
         tc.save({"conanfile.py": GenConanfile("lib", "1.0")})
 
-        tc.run("graph info . -f json --build=never --no-remote --filter=context", redirect_stdout="graph_context.json")
+        tc.run("graph info . -f json --build=never --no-remote --filter=context",
+               redirect_stdout="graph_context.json")
 
         tc.run("list --graph=graph_context.json --graph-context=build-only --format=json",
                assert_error=True)
