@@ -56,7 +56,7 @@ _sbom_zlib_1_2_11 = """
 
 @contextmanager
 def proxy_response(status, data, retry_after=60):
-    with patch("conan.api.conan_api.RemotesAPI.requester") as conanRequesterMock:
+    with patch("conan.api.conan_api.ConanAPI._ApiHelpers.requester") as conanRequesterMock:
         return_status = MagicMock()
         return_status.status_code = status
         return_status.json = MagicMock(return_value=data)
@@ -140,6 +140,13 @@ def test_conan_audit_proxy():
         tc.run("audit scan --requires=zlib/1.2.11")
         assert "zlib/1.2.11 1 vulnerability found" in tc.out
 
+        tc.save({"conanfile.txt": "[requires]\nzlib/1.2.11\n"}, clean_first=True)
+        tc.run("audit scan")
+        assert "zlib/1.2.11 1 vulnerability found" in tc.out
+
+        tc.run("audit scan . --requires=zlib/1.2.11", assert_error=True)
+        assert "--requires and --tool-requires arguments are incompatible with [path] '.' argument" in tc.out
+
     # Now some common errors, like rate limited or missing lib, but it should not fail!
     with proxy_response(429, {"error": "Rate limit exceeded"}):
         tc.run("audit list zlib/1.2.11", assert_error=True)
@@ -350,7 +357,7 @@ def test_audit_provider_env_credentials_with_proxy(monkeypatch):
         return response
 
     with environment_update({"CONAN_AUDIT_PROVIDER_TOKEN_CONANCENTER": "env_token_value"}):
-        with patch("conan.api.conan_api.RemotesAPI.requester",
+        with patch("conan.api.conan_api.ConanAPI._ApiHelpers.requester",
                    new_callable=MagicMock) as requester_mock:
             requester_mock.post = fake_post
             tc.run("audit list zlib/1.2.11")
@@ -472,3 +479,23 @@ def test_parse_error_crash_when_no_edges():
     assert "conan_error" in scan_result
     assert "zlib/1.2.11" in scan_result["conan_error"]
     assert "7.0" in scan_result["conan_error"]
+
+
+@pytest.mark.parametrize("package_context", ["build", "host"])
+@pytest.mark.parametrize("filter_context", ["build", "host", None])
+def test_audit_scan_context_filter(package_context, filter_context):
+    tc = TestClient(light=True)
+
+    tc.save({"conanfile.py": GenConanfile("zlib", "1.2.11")})
+    tc.run("export .")
+    tc.run("audit provider auth conancenter --token=valid_token")
+
+    requires = "requires" if package_context == "host" else "tool-requires"
+    context = "" if filter_context is None else f"--context={filter_context}"
+
+    with proxy_response(200, {}):
+        tc.run(f"audit scan --{requires}=zlib/1.2.11 {context}")
+        if filter_context is None or filter_context == package_context:
+            assert "Requesting vulnerability info for: zlib/1.2.11" in tc.out
+        else:
+            assert "Requesting vulnerability info for: zlib/1.2.11" not in tc.out
