@@ -4,7 +4,7 @@ import textwrap
 import pytest
 
 from conan.test.assets.genconanfile import GenConanfile
-from conan.test.utils.tools import NO_SETTINGS_PACKAGE_ID, TestClient
+from conan.test.utils.tools import TestClient
 
 
 def test_user_overrides():
