@@ -1,7 +1,6 @@
 import pytest
 
 from conan.test.utils.tools import GenConanfile, TestClient
-from conan.internal.util.files import save
 
 
 @pytest.mark.parametrize("build_mode", [None, "patch_mode"])
@@ -11,7 +10,7 @@ def test_package_id_not_affected_test_requires(build_mode):
     """
     c = TestClient()
     if build_mode is not None:
-        save(c.paths.new_config_path, "core.package_id:default_build_mode={build_mode}")
+        c.save_home({"global.conf": f"core.package_id:default_build_mode={build_mode}"})
     c.save({"gtest/conanfile.py": GenConanfile("gtest", "1.0"),
             "engine/conanfile.py": GenConanfile("engine", "1.0").with_test_requires("gtest/1.0")})
     c.run("create gtest")
