@@ -145,11 +145,11 @@ def test_cmakedeps_deployer_relative_paths():
     liba_config = c.load("liba-config.cmake")
     assert ('include("${CMAKE_CURRENT_LIST_DIR}/full_deploy/'
             'host/liba/1.0/share/cmake/crypto.cmake")') in liba_config
+    assert ('set(liba_INCLUDE_DIRS "${CMAKE_CURRENT_LIST_DIR}/full_deploy/'
+            'host/liba/1.0/includea" )') in liba_config
     liba_targets = c.load("liba-Targets-release.cmake")
     assert ('set(liba_PACKAGE_FOLDER_RELEASE "${CMAKE_CURRENT_LIST_DIR}/full_deploy/'
             'host/liba/1.0")') in liba_targets
-    assert ('set(liba_INCLUDE_DIRS "${CMAKE_CURRENT_LIST_DIR}/full_deploy/'
-            'host/liba/1.0/includea" )') in liba_targets
 
 
 def test_cmakeconfigdeps_recipe():
@@ -388,103 +388,161 @@ def test_cmake_find_mode_deprecated():
     assert "CMakeConfigDeps does not support module find mode"
 
 
-def test_requires_to_application():
-    c = TestClient()
-    automake = textwrap.dedent("""
-        from conan import ConanFile
-        class Dependent(ConanFile):
-            name = "automake"
-            version = "0.1"
-            package_type = "application"
-        """)
-
-    conanfile = textwrap.dedent("""
+def test_cmake_extra_dependencies():
+    tc = TestClient()
+    dep = textwrap.dedent("""
         from conan import ConanFile
         class Pkg(ConanFile):
-            name = "libtool"
+            name = "dep"
             version = "0.1"
-            package_type = "static-library"
-
-            def requirements(self):
-                self.requires('automake/0.1')
-        """)
-    test_package = textwrap.dedent("""
-        from conan import ConanFile
-        from conan.tools.cmake import CMake
-
-        class TestPkg(ConanFile):
-            settings = "os", "compiler", "arch", "build_type"
-            generators = "CMakeDeps", "CMakeToolchain"
-
-            def requirements(self):
-                self.requires(self.tested_reference_str)
-
-            def test(self):
-                pass
-        """)
-
-    c.save({"automake/conanfile.py": automake,
-            "libtool/conanfile.py": conanfile,
-            "libtool/test_package/conanfile.py": test_package})
-    c.run("create automake")
-    c.run(f"create libtool -c tools.cmake.cmakedeps:new={new_value}")
-    targets = c.load("libtool/test_package/libtool-Targets-release.cmake")
-    # The libtool shouldn't depend on the automake::automake target
-    assert "automake::automake" not in targets
-
-
-def test_requires_to_application_component():
-    c = TestClient()
-    automake = textwrap.dedent("""
-        from conan import ConanFile
-        class Dependent(ConanFile):
-            name = "automake"
-            version = "0.1"
-            package_type = "application"
-
             def package_info(self):
-                self.cpp_info.components["myapp"].exe = "myapp"
-                self.cpp_info.components["myapp"].location = "path/to/myapp"
-                self.cpp_info.components["mylibapp"].type = "header-library"
+                self.cpp_info.set_property("cmake_extra_dependencies", ["MyOpenMPI"])
+                self.cpp_info.set_property("cmake_extra_interface_libs", ["MyOpenMPILib"])
         """)
+    tc.save({"conanfile.py": dep})
+    tc.run("create .")
+    args = f"-g CMakeDeps -c tools.cmake.cmakedeps:new={new_value}"
+    tc.run(f"install --requires=dep/0.1 {args}")
+    dep = tc.load("dep-Targets-release.cmake")
+    assert "find_dependency(MyOpenMPI REQUIRED )" in dep
+    assert "set_property(TARGET dep::dep APPEND PROPERTY INTERFACE_LINK_LIBRARIES\n" \
+           "             $<$<CONFIG:RELEASE>:MyOpenMPILib>)" in dep
 
-    conanfile = textwrap.dedent("""
-        from conan import ConanFile
-        class Pkg(ConanFile):
-            name = "libtool"
-            version = "0.1"
-            package_type = "static-library"
 
-            def requirements(self):
-                self.requires('automake/0.1')
-            def package_info(self):
-                self.cpp_info.requires = ["automake::mylibapp"]
-        """)
-    test_package = textwrap.dedent("""
-        from conan import ConanFile
-        from conan.tools.cmake import CMake
+class TestRequiresToApp:
+    def test_requires_to_application(self):
+        c = TestClient()
+        automake = GenConanfile("automake", "0.1").with_package_type("application")
+        conanfile = (GenConanfile("libtool", "0.1").with_package_type("static-library")
+                                                   .with_requirement("automake/0.1"))
+        test_package = textwrap.dedent("""
+            from conan import ConanFile
+            from conan.tools.cmake import CMake
 
-        class TestPkg(ConanFile):
-            settings = "os", "compiler", "arch", "build_type"
-            generators = "CMakeDeps", "CMakeToolchain"
+            class TestPkg(ConanFile):
+                settings = "os", "compiler", "arch", "build_type"
+                generators = "CMakeDeps", "CMakeToolchain"
 
-            def requirements(self):
-                self.requires(self.tested_reference_str)
+                def requirements(self):
+                    self.requires(self.tested_reference_str)
 
-            def test(self):
-                pass
-        """)
+                def test(self):
+                    pass
+            """)
+
+        c.save({"automake/conanfile.py": automake,
+                "libtool/conanfile.py": conanfile,
+                "libtool/test_package/conanfile.py": test_package})
+        c.run("create automake")
+        c.run(f"create libtool -c tools.cmake.cmakedeps:new={new_value}")
+        targets = c.load("libtool/test_package/libtool-Targets-release.cmake")
+        # The libtool shouldn't depend on the automake::automake target
+        assert "automake::automake" not in targets
+
+    def test_requires_to_application_component(self):
+        c = TestClient()
+        automake = textwrap.dedent("""
+            from conan import ConanFile
+            class Dependent(ConanFile):
+                name = "automake"
+                version = "0.1"
+                package_type = "application"
+
+                def package_info(self):
+                    self.cpp_info.components["myapp"].exe = "myapp"
+                    self.cpp_info.components["myapp"].location = "path/to/myapp"
+                    self.cpp_info.components["mylibapp"].type = "header-library"
+            """)
+
+        conanfile = textwrap.dedent("""
+            from conan import ConanFile
+            class Pkg(ConanFile):
+                name = "libtool"
+                version = "0.1"
+                package_type = "static-library"
+
+                def requirements(self):
+                    self.requires('automake/0.1')
+                def package_info(self):
+                    self.cpp_info.requires = ["automake::mylibapp"]
+            """)
+
+        c.save({"automake/conanfile.py": automake,
+                "libtool/conanfile.py": conanfile})
+        c.run("create automake")
+
+        c.run("create libtool")
+        c.run("install --requires=libtool/0.1 -g CMakeDeps "
+              f"-c tools.cmake.cmakedeps:new={new_value}")
+        targets = c.load("libtool-Targets-release.cmake")
+        # The libtool shouldn't depend on the automake::automake target
+        assert "automake::automake" not in targets
+        assert "# Requirement automake::mylibapp => Full link: True" in targets
+        assert "$<$<CONFIG:RELEASE>:automake::mylibapp>" in targets
+
+    def test_requires_from_library_component(self):
+        c = TestClient()
+        automake = GenConanfile("automake", "0.1").with_package_type("application")
+        conanfile = textwrap.dedent("""
+            from conan import ConanFile
+            class Pkg(ConanFile):
+                name = "libtool"
+                version = "0.1"
+                package_type = "static-library"
+
+                def requirements(self):
+                    self.requires('automake/0.1')
+                def package_info(self):
+                    self.cpp_info.components["mycomp"].requires = ["automake::automake"]
+            """)
+
+        c.save({"automake/conanfile.py": automake,
+                "libtool/conanfile.py": conanfile})
+        c.run("create automake")
+        c.run("create libtool")
+        c.run("install --requires=libtool/0.1 -g CMakeDeps "
+              f"-c tools.cmake.cmakedeps:new={new_value}")
+        targets = c.load("libtool-Targets-release.cmake")
+        # The libtool shouldn't depend on the automake::automake target
+        assert "automake::automake" not in targets
+
+    def test_requires_from_library_component_to_app_component(self):
+        c = TestClient()
+        automake = textwrap.dedent("""
+            from conan import ConanFile
+            class Dependent(ConanFile):
+                name = "automake"
+                version = "0.1"
+
+                def package_info(self):
+                    self.cpp_info.components["myapp"].exe = "myapp"
+                    self.cpp_info.components["myapp"].location = "path/to/myapp"
+                    self.cpp_info.components["mylibapp"].type = "header-library"
+            """)
+        conanfile = textwrap.dedent("""
+            from conan import ConanFile
+            class Pkg(ConanFile):
+                name = "libtool"
+                version = "0.1"
+                package_type = "static-library"
+
+                def requirements(self):
+                    self.requires('automake/0.1')
+                def package_info(self):
+                    self.cpp_info.components["mycomp"].requires = ["automake::myapp"]
+            """)
+
+        c.save({"automake/conanfile.py": automake,
+                "libtool/conanfile.py": conanfile})
+        c.run("create automake")
+        c.run("create libtool")
+        c.run("install --requires=libtool/0.1 -g CMakeDeps "
+              f"-c tools.cmake.cmakedeps:new={new_value}")
+        targets = c.load("libtool-Targets-release.cmake")
+        # The libtool shouldn't depend on the automake::automake target
+        assert "automake::myapp" not in targets
+        assert "automake::automake" not in targets
 
-    c.save({"automake/conanfile.py": automake,
-            "libtool/conanfile.py": conanfile,
-            "libtool/test_package/conanfile.py": test_package})
-    c.run("create automake")
-    c.run(f"create libtool -c tools.cmake.cmakedeps:new={new_value}")
-    targets = c.load("libtool/test_package/libtool-Targets-release.cmake")
-    # The libtool shouldn't depend on the automake::automake target
-    assert "automake::automake" not in targets
-    assert "# Requirement automake::mylibapp => Full link: True" in targets
-    assert "$<$<CONFIG:RELEASE>:automake::mylibapp>" in targets
 
 
 def test_alias_cmakedeps_set_property():
@@ -526,3 +584,34 @@ def test_alias_cmakedeps_set_property():
 
     assert "add_library(component_alias" in targets_data
     assert "add_library(dep::my_aliased_component" in targets_data
+
+
+def test_package_info_extra_variables():
+    """ Test extra_variables property - This just shows that it works,
+    there are tests for cmaketoolchain that check the actual behavior
+    of parsing the variables"""
+    client = TestClient()
+    conanfile = textwrap.dedent("""
+        from conan import ConanFile
+
+        class Pkg(ConanFile):
+            name = "pkg"
+            version = "0.1"
+
+            def package_info(self):
+                self.cpp_info.set_property("cmake_extra_variables", {"FOO": 42,
+                                           "BAR": 42,
+                                           "CMAKE_GENERATOR_INSTANCE": "${GENERATOR_INSTANCE}/buildTools/",
+                                           "CACHE_VAR_DEFAULT_DOC": {"value": "hello world",
+                                                                     "cache": True, "type": "PATH"}})
+    """)
+    client.save({"conanfile.py": conanfile})
+    client.run("create .")
+
+    client.run(f"install --requires=pkg/0.1 -g CMakeDeps -c tools.cmake.cmakedeps:new={new_value} "
+               """-c tools.cmake.cmaketoolchain:extra_variables="{'BAR': 9}" """)
+    target = client.load("pkg-config.cmake")
+    assert 'set(BAR' not in target
+    assert 'set(CMAKE_GENERATOR_INSTANCE "${GENERATOR_INSTANCE}/buildTools/")' in target
+    assert 'set(FOO 42)' in target
+    assert 'set(CACHE_VAR_DEFAULT_DOC "hello world" CACHE PATH "CACHE_VAR_DEFAULT_DOC")' in target
