@@ -7,7 +7,7 @@ from conan.api.conan_api import ConanAPI
 from conan.internal.cache.home_paths import HomePaths
 from conan.errors import ConanException
 from conan.test.utils.test_files import temp_folder
-from conans.util.files import save
+from conan.internal.util.files import save
 
 
 @pytest.fixture()
