@@ -1,4 +1,3 @@
-import unittest
 
 from conan.api.output import ConanOutput
 from conan.internal.model.manifest import FileTreeManifest
@@ -6,7 +5,7 @@ from conan.test.utils.mocks import RedirectedTestOutput
 from conan.test.utils.tools import redirect_output
 
 
-class ReportCopiedFilesTestCase(unittest.TestCase):
+class TestReportCopiedFiles:
 
     def test_output_string(self):
         manifest = FileTreeManifest(0,
@@ -24,6 +23,6 @@ class ReportCopiedFilesTestCase(unittest.TestCase):
         with redirect_output(output):
             manifest.report_summary(ConanOutput())
             lines = sorted(str(output).splitlines())
-            self.assertEqual("Copied 7 '.pdf' files", lines[2])
-            self.assertEqual("Copied 2 files: no_ext1, no_ext2", lines[1])
-            self.assertEqual("Copied 1 '.txt' file: other.txt", lines[0])
+            assert "Copied 7 '.pdf' files" == lines[2]
+            assert "Copied 2 files: no_ext1, no_ext2" == lines[1]
+            assert "Copied 1 '.txt' file: other.txt" == lines[0]
