@@ -1,6 +1,4 @@
 import textwrap
-import unittest
-
 import pytest
 
 from conan.internal.default_settings import default_settings_yml
@@ -12,30 +10,30 @@ def undefined_value(v):
     return "'%s' value not defined" % v
 
 
-class SettingsLoadsTest(unittest.TestCase):
+class TestSettingsLoads:
 
     def test_none_value(self):
         yml = "os: [null, Windows]"
         settings = Settings.loads(yml)
         settings.validate()
-        self.assertTrue(settings.os == None)
-        self.assertEqual("", settings.dumps())
+        assert settings.os == None
+        assert "" == settings.dumps()
         settings.os = "Windows"
-        self.assertTrue(settings.os == "Windows")
-        self.assertEqual("os=Windows", settings.dumps())
+        assert settings.os == "Windows"
+        assert "os=Windows" == settings.dumps()
 
     def test_any(self):
         yml = "os: [ANY]"
         settings = Settings.loads(yml)
-        with self.assertRaisesRegex(ConanException, "'settings.os' value not defined"):
+        with pytest.raises(ConanException, match="'settings.os' value not defined"):
             settings.validate()  # Raise exception if unset
         settings.os = "some-os"
         settings.validate()
-        self.assertTrue(settings.os == "some-os")
-        self.assertIn("os=some-os", settings.dumps())
+        assert settings.os == "some-os"
+        assert "os=some-os" in settings.dumps()
         settings.os = "Windows"
-        self.assertTrue(settings.os == "Windows")
-        self.assertEqual("os=Windows", settings.dumps())
+        assert settings.os == "Windows"
+        assert "os=Windows" == settings.dumps()
 
     def test_none_any(self):
         yml = "os: [null, ANY]"
@@ -43,11 +41,11 @@ class SettingsLoadsTest(unittest.TestCase):
         settings.validate()
         settings.os = "None"
         settings.validate()
-        self.assertTrue(settings.os == "None")
-        self.assertIn("os=None", settings.dumps())
+        assert settings.os == "None"
+        assert "os=None" in settings.dumps()
         settings.os = "Windows"
-        self.assertTrue(settings.os == "Windows")
-        self.assertEqual("os=Windows", settings.dumps())
+        assert settings.os == "Windows"
+        assert "os=Windows" == settings.dumps()
 
     def test_nested_any(self):
         yml = textwrap.dedent("""\
@@ -60,39 +58,38 @@ class SettingsLoadsTest(unittest.TestCase):
         settings = Settings.loads(yml)
         settings.os = "Windows"
         settings.validate()
-        self.assertTrue(settings.os == "Windows")
-        self.assertIn("os=Windows", settings.dumps())
+        assert settings.os == "Windows"
+        assert "os=Windows" in settings.dumps()
         settings.os.version = 2
-        self.assertTrue(settings.os == "Windows")
-        self.assertEqual("os=Windows\nos.version=2", settings.dumps())
+        assert settings.os == "Windows"
+        assert "os=Windows\nos.version=2" == settings.dumps()
         settings.os = "Ubuntu"
-        with self.assertRaisesRegex(ConanException, "'settings.os.version' value not defined"):
+        with pytest.raises(ConanException, match="'settings.os.version' value not defined"):
             settings.validate()
-        with self.assertRaisesRegex(ConanException,
-                                    "Invalid setting '3' is not a valid 'settings.os.version'"):
+        with pytest.raises(ConanException, match="Invalid setting '3' is not a valid 'settings.os.version'"):
             settings.os.version = 3
         settings.os.version = "20.04"
-        self.assertEqual("os=Ubuntu\nos.version=20.04", settings.dumps())
-        self.assertTrue(settings.os.version == "20.04")
+        assert "os=Ubuntu\nos.version=20.04" == settings.dumps()
+        assert settings.os.version == "20.04"
 
     def test_getattr_none(self):
         yml = "os: [None, Windows]"
         settings = Settings.loads(yml)
-        self.assertEqual(settings.os, None)
+        assert settings.os == None
         _os = getattr(settings, "os")
-        self.assertEqual(_os, None)
-        self.assertEqual(str(_os), "None")
+        assert _os == None
+        assert str(_os) == "None"
 
     def test_get_safe(self):
         yml = "os: [None, Windows]"
         settings = Settings.loads(yml)
         settings.os = "Windows"
-        self.assertEqual(settings.os, "Windows")
-        self.assertEqual(settings.get_safe("compiler.version"), None)
-        self.assertEqual(settings.get_safe("build_type"), None)
-        self.assertEqual("Release", settings.get_safe("build_type", "Release"))
-        self.assertEqual(False, settings.get_safe("build_type", False))
-        self.assertEqual("Windows", settings.get_safe("os", "Linux"))
+        assert settings.os == "Windows"
+        assert settings.get_safe("compiler.version") == None
+        assert settings.get_safe("build_type") == None
+        assert "Release" == settings.get_safe("build_type", "Release")
+        assert False == settings.get_safe("build_type", False)
+        assert "Windows" == settings.get_safe("os", "Linux")
 
     def test_none_subsetting(self):
         yml = """os:
@@ -102,14 +99,14 @@ class SettingsLoadsTest(unittest.TestCase):
 """
         settings = Settings.loads(yml)
         settings.validate()
-        self.assertTrue(settings.os == None)
-        self.assertEqual("", settings.dumps())
+        assert settings.os == None
+        assert "" == settings.dumps()
         settings.os = "Windows"
-        self.assertTrue(settings.os.subsystem == None)
-        self.assertEqual("os=Windows", settings.dumps())
+        assert settings.os.subsystem == None
+        assert "os=Windows" == settings.dumps()
         settings.os.subsystem = "cygwin"
         settings.validate()
-        self.assertEqual("os=Windows\nos.subsystem=cygwin", settings.dumps())
+        assert "os=Windows\nos.subsystem=cygwin" == settings.dumps()
 
     def test_none__sub_subsetting(self):
         yml = """os:
@@ -117,14 +114,14 @@ class SettingsLoadsTest(unittest.TestCase):
         subsystem: [null, cygwin]
     Windows:
 """
-        with self.assertRaisesRegex(ConanException,
-                                    "settings.yml: null setting can't have subsettings"):
+        with pytest.raises(ConanException, match="settings.yml: null setting can't have subsettings"):
             Settings.loads(yml)
 
 
-class SettingsTest(unittest.TestCase):
+class TestSettings:
 
-    def setUp(self):
+    @pytest.fixture(autouse=True)
+    def setup(self):
         data = {"compiler": {
                             "Visual Studio": {
                                              "version": ["10", "11", "12"],
@@ -139,8 +136,8 @@ class SettingsTest(unittest.TestCase):
 
     def test_in_contains(self):
         self.sut.compiler = "Visual Studio"
-        self.assertTrue("Visual" in self.sut.compiler)
-        self.assertFalse("Visual" not in self.sut.compiler)
+        assert "Visual" in self.sut.compiler
+        assert not ("Visual" not in self.sut.compiler)
 
     def test_os_split(self):
         settings = Settings.loads("""os:
@@ -153,13 +150,13 @@ class SettingsTest(unittest.TestCase):
         other_settings = Settings.loads("os: [Windows, Linux]")
         settings.os = "Windows"
         other_settings.os = "Windows"
-        self.assertEqual(settings.dumps(), other_settings.dumps())
+        assert settings.dumps() == other_settings.dumps()
 
     def test_any(self):
         data = {"target": ["ANY"]}
         sut = Settings(data)
         sut.target = "native"
-        self.assertTrue(sut.target == "native")
+        assert sut.target == "native"
 
     def test_multi_os(self):
         settings = Settings.loads("""os:
@@ -170,23 +167,23 @@ class SettingsTest(unittest.TestCase):
                 codename: [Mavericks, Yosemite]
         """)
         settings.os = "Windows"
-        self.assertEqual(settings.os, "Windows")
+        assert settings.os == "Windows"
         settings.os = "Linux"
         settings.os.distro = "RH6"
-        self.assertTrue(settings.os.distro == "RH6")
-        with self.assertRaises(ConanException):
+        assert settings.os.distro == "RH6"
+        with pytest.raises(ConanException):
             settings.os.distro = "Other"
-        with self.assertRaises(ConanException):
+        with pytest.raises(ConanException):
             settings.os.codename = "Yosemite"
         settings.os = "Macos"
         settings.os.codename = "Yosemite"
-        self.assertTrue(settings.os.codename == "Yosemite")
+        assert settings.os.codename == "Yosemite"
 
     def test_remove(self):
         del self.sut.compiler
         self.sut.os = "Windows"
         self.sut.validate()
-        self.assertEqual(self.sut.dumps(), "os=Windows")
+        assert self.sut.dumps() == "os=Windows"
 
     def test_loads_default(self):
         settings = Settings.loads("""os: [Windows, Linux, Macos, Android, FreeBSD, SunOS]
@@ -205,8 +202,8 @@ compiler:
 build_type: [None, Debug, Release]""")
         settings.compiler = "clang"
         settings.compiler.version = "3.5"
-        self.assertEqual(settings.compiler, "clang")
-        self.assertEqual(settings.compiler.version, "3.5")
+        assert settings.compiler == "clang"
+        assert settings.compiler.version == "3.5"
 
     def test_loads(self):
         settings = Settings.loads("""
@@ -233,10 +230,9 @@ os: [Windows, Linux]
         settings.update_values([('compiler', 'msvc'),
                                 ('compiler.version', '10'),
                                 ('compiler.version.arch', '32')])
-        self.assertEqual(settings.values_list,
-                         [('compiler', 'msvc'),
+        assert settings.values_list == [('compiler', 'msvc'),
                           ('compiler.version', '10'),
-                          ('compiler.version.arch', '32')])
+                          ('compiler.version.arch', '32')]
 
         settings.compiler.version = "10"
         settings.compiler.version.arch = "32"
@@ -245,180 +241,168 @@ os: [Windows, Linux]
         settings.compiler.version = "12"
         settings.compiler.version.arch = "64"
 
-        self.assertEqual(settings.values_list,
-                         [('compiler', 'msvc'),
+        assert settings.values_list == [('compiler', 'msvc'),
                           ('compiler.version', '12'),
-                          ('compiler.version.arch', '64')])
+                          ('compiler.version.arch', '64')]
 
     def test_set_value(self):
         self.sut.update_values([("compiler", "Visual Studio")])
-        self.assertEqual(self.sut.compiler, "Visual Studio")
+        assert self.sut.compiler == "Visual Studio"
         self.sut.update_values([("compiler.version", "12")])
-        self.assertEqual(self.sut.compiler.version, "12")
+        assert self.sut.compiler.version == "12"
         self.sut.update_values([("compiler", "gcc")])
-        self.assertEqual(self.sut.compiler, "gcc")
+        assert self.sut.compiler == "gcc"
         self.sut.update_values([("compiler.version", "4.8")])
-        self.assertEqual(self.sut.compiler.version, "4.8")
+        assert self.sut.compiler.version == "4.8"
         self.sut.update_values([("compiler.arch", "x86")])
-        self.assertEqual(self.sut.compiler.arch, "x86")
+        assert self.sut.compiler.arch == "x86"
         self.sut.update_values([("compiler.arch.speed", "A")])
-        self.assertEqual(self.sut.compiler.arch.speed, "A")
+        assert self.sut.compiler.arch.speed == "A"
 
     def test_constraint(self):
         s2 = ["os"]
         self.sut.constrained(s2)
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler
-        self.assertEqual(str(cm.exception),
-                         str(undefined_field("settings", "compiler", ["os"], "settings")))
+        assert str(cm.value) == str(undefined_field("settings", "compiler", ["os"], "settings"))
         self.sut.os = "Windows"
         self.sut.os = "Linux"
 
     def test_constraint2(self):
         s2 = ["os2"]
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.constrained(s2)
-        self.assertEqual(str(cm.exception),
-                         str(undefined_field("settings", "os2", ["compiler", "os"], "settings")))
+        assert str(cm.value) == str(undefined_field("settings", "os2", ["compiler", "os"], "settings"))
 
     def test_constraint6(self):
         s2 = {"os", "compiler"}
         self.sut.constrained(s2)
         self.sut.compiler = "Visual Studio"
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler.arch
-        self.assertEqual(str(cm.exception), str(undefined_field("settings.compiler", "arch",
-                                                                ['runtime', 'version'], "Visual Studio")))
+        assert str(cm.value) == str(undefined_field("settings.compiler", "arch",
+                                                                ['runtime', 'version'], "Visual Studio"))
         self.sut.os = "Windows"
         self.sut.compiler.version = "11"
         self.sut.compiler.version = "12"
 
     def test_validate(self):
-        with self.assertRaisesRegex(ConanException, str(undefined_value("settings.compiler"))):
+        with pytest.raises(ConanException, match=str(undefined_value("settings.compiler"))):
             self.sut.validate()
 
         self.sut.compiler = "gcc"
-        with self.assertRaisesRegex(ConanException, "value not defined"):
+        with pytest.raises(ConanException, match="value not defined"):
             self.sut.validate()
 
         self.sut.compiler.arch = "x86"
-        with self.assertRaisesRegex(ConanException, "value not defined"):
+        with pytest.raises(ConanException, match="value not defined"):
             self.sut.validate()
 
         self.sut.compiler.arch.speed = "A"
-        with self.assertRaisesRegex(ConanException, "value not defined"):
+        with pytest.raises(ConanException, match="value not defined"):
             self.sut.validate()
 
         self.sut.compiler.version = "4.8"
-        with self.assertRaisesRegex(ConanException, "value not defined"):
+        with pytest.raises(ConanException, match="value not defined"):
             self.sut.validate()
 
         self.sut.os = "Windows"
         self.sut.validate()
-        self.assertEqual(self.sut.values_list, [("compiler", "gcc"),
+        assert self.sut.values_list == [("compiler", "gcc"),
                                                 ("compiler.arch", "x86"),
                                                 ("compiler.arch.speed", "A"),
                                                 ("compiler.version", "4.8"),
-                                                ("os", "Windows")])
+                                                ("os", "Windows")]
 
     def test_validate2(self):
         self.sut.os = "Windows"
         self.sut.compiler = "Visual Studio"
-        with self.assertRaisesRegex(ConanException, "value not defined"):
+        with pytest.raises(ConanException, match="value not defined"):
             self.sut.validate()
 
         self.sut.compiler.runtime = "MD"
-        with self.assertRaisesRegex(ConanException, "value not defined"):
+        with pytest.raises(ConanException, match="value not defined"):
             self.sut.validate()
 
         self.sut.compiler.version = "10"
         self.sut.validate()
 
-        self.assertEqual(self.sut.values_list, [("compiler", "Visual Studio"),
+        assert self.sut.values_list == [("compiler", "Visual Studio"),
                                                 ("compiler.runtime", "MD"),
                                                 ("compiler.version", "10"),
-                                                ("os", "Windows")])
+                                                ("os", "Windows")]
 
     def test_basic(self):
         s = Settings({"os": ["Windows", "Linux"]})
         s.os = "Windows"
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler = "kk"
-        self.assertEqual(str(cm.exception),
-                         bad_value_msg("settings.compiler", "kk", ['Visual Studio', 'gcc']))
+        assert str(cm.value) == bad_value_msg("settings.compiler", "kk", ['Visual Studio', 'gcc'])
 
     def test_my(self):
-        self.assertEqual(self.sut.compiler, None)
+        assert self.sut.compiler == None
 
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler = "kk"
-        self.assertEqual(str(cm.exception),
-                         bad_value_msg("settings.compiler", "kk", ['Visual Studio', 'gcc']))
+        assert str(cm.value) == bad_value_msg("settings.compiler", "kk", ['Visual Studio', 'gcc'])
 
         self.sut.compiler = "Visual Studio"
-        self.assertEqual(str(self.sut.compiler), "Visual Studio")
-        self.assertEqual(self.sut.compiler, "Visual Studio")
+        assert str(self.sut.compiler) == "Visual Studio"
+        assert self.sut.compiler == "Visual Studio"
 
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler.kk
-        self.assertEqual(str(cm.exception),
-                         str(undefined_field("settings.compiler", "kk", ['runtime', 'version'],
-                                             "Visual Studio")))
+        assert str(cm.value) == str(undefined_field("settings.compiler", "kk", ['runtime', 'version'],
+                                             "Visual Studio"))
 
-        self.assertEqual(self.sut.compiler.version, None)
+        assert self.sut.compiler.version == None
 
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler.version = "123"
-        self.assertEqual(str(cm.exception),
-                         bad_value_msg("settings.compiler.version", "123", ['10', '11', '12']))
+        assert str(cm.value) == bad_value_msg("settings.compiler.version", "123", ['10', '11', '12'])
 
         self.sut.compiler.version = "12"
-        self.assertEqual(self.sut.compiler.version, "12")
-        self.assertEqual(str(self.sut.compiler.version), "12")
+        assert self.sut.compiler.version == "12"
+        assert str(self.sut.compiler.version) == "12"
 
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             assert self.sut.compiler == "kk"
-        self.assertEqual(str(cm.exception),
-                         bad_value_msg("settings.compiler", "kk", ['Visual Studio', 'gcc']))
+        assert str(cm.value) == bad_value_msg("settings.compiler", "kk", ['Visual Studio', 'gcc'])
 
-        self.assertFalse(self.sut.compiler == "gcc")
-        self.assertTrue(self.sut.compiler == "Visual Studio")
+        assert not (self.sut.compiler == "gcc")
+        assert self.sut.compiler == "Visual Studio"
 
-        self.assertTrue(self.sut.compiler.version == "12")
-        self.assertFalse(self.sut.compiler.version == "11")
+        assert self.sut.compiler.version == "12"
+        assert not (self.sut.compiler.version == "11")
 
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             assert self.sut.compiler.version == "13"
-        self.assertEqual(str(cm.exception),
-                         bad_value_msg("settings.compiler.version", "13", ['10', '11', '12']))
+        assert str(cm.value) == bad_value_msg("settings.compiler.version", "13", ['10', '11', '12'])
 
         self.sut.compiler = "gcc"
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler.runtime
-        self.assertEqual(str(cm.exception),
-                         str(undefined_field("settings.compiler", "runtime", "['arch', 'version']",
-                                             "gcc")))
+        assert str(cm.value) == str(undefined_field("settings.compiler", "runtime", "['arch', 'version']",
+                                             "gcc"))
 
         self.sut.compiler.arch = "x86"
         self.sut.compiler.arch.speed = "A"
-        self.assertEqual(self.sut.compiler.arch.speed, "A")
+        assert self.sut.compiler.arch.speed == "A"
 
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler.arch.speed = "D"
-        self.assertEqual(str(cm.exception),
-                         bad_value_msg("settings.compiler.arch.speed", "D", ['A', 'B']))
+        assert str(cm.value) == bad_value_msg("settings.compiler.arch.speed", "D", ['A', 'B'])
 
         self.sut.compiler.arch = "x64"
         self.sut.compiler.arch.speed = "C"
-        self.assertEqual(self.sut.compiler.arch.speed, "C")
+        assert self.sut.compiler.arch.speed == "C"
 
-        with self.assertRaises(ConanException) as cm:
+        with pytest.raises(ConanException) as cm:
             self.sut.compiler.arch.speed = "A"
-        self.assertEqual(str(cm.exception),
-                         bad_value_msg("settings.compiler.arch.speed", "A", ['C', 'D']))
+        assert str(cm.value) == bad_value_msg("settings.compiler.arch.speed", "A", ['C', 'D'])
 
         self.sut.compiler.arch.speed = "D"
-        self.assertEqual(self.sut.compiler.arch.speed, "D")
+        assert self.sut.compiler.arch.speed == "D"
 
 
 def test_possible_values():
