@@ -245,7 +245,7 @@ def test_osx_deployment_target(conanfile_apple):
 def conanfile_msvc():
     c = ConanFile(None)
     c.settings = Settings({"os": ["Windows"],
-                           "compiler": {"msvc": {"version": ["193", "194"], "cppstd": ["20"],
+                           "compiler": {"msvc": {"version": ["193", "194", "195"], "cppstd": ["20"],
                                                  "update": [None, 8, 9]}},
                            "build_type": ["Release"],
                            "arch": ["x86"]})
@@ -272,6 +272,13 @@ def test_toolset(conanfile_msvc):
     assert 'CMAKE_CXX_STANDARD 20' in toolchain.content
 
 
+def test_toolset_latest_generator(conanfile_msvc):
+    conanfile_msvc.settings.compiler.version="195"
+    toolchain = CMakeToolchain(conanfile_msvc)
+    assert 'set(CMAKE_GENERATOR_TOOLSET "v145" CACHE STRING "" FORCE)' in toolchain.content
+    assert 'Visual Studio 18 2026' in toolchain.generator
+
+
 def test_toolset_update_version(conanfile_msvc):
     conanfile_msvc.settings.compiler.version = "193"
     conanfile_msvc.settings.compiler.update = "8"
