@@ -232,7 +232,8 @@ def test_windows_case_insensitive_bat(envvars):
 
 
 @pytest.mark.skipif(platform.system() != "Windows", reason="Requires Windows")
-def test_windows_case_insensitive_ps1(envvars):
+@pytest.mark.parametrize("deactivation_mode", ["function", None],)
+def test_windows_case_insensitive_ps1(envvars, deactivation_mode):
     display = textwrap.dedent("""\
         echo "MyVar=$env:MyVar!!"
         echo "MyVar1=$env:MyVar1!!"
@@ -245,9 +246,11 @@ def test_windows_case_insensitive_ps1(envvars):
     prevenv.update(dict(os.environ.copy()))
 
     with chdir(temp_folder()):
+        envvars._deactivation_mode = deactivation_mode
         envvars.save_ps1("test.ps1")
         save("display.ps1", display)
-        cmd = "powershell.exe .\\test.ps1 ; .\\display.ps1 ; .\\deactivate_test.ps1 ; .\\display.ps1"
+        deactivate_cmd = "deactivate_test" if deactivation_mode else ".\\deactivate_test.ps1"
+        cmd = f"powershell.exe .\\test.ps1 ; .\\display.ps1 ; {deactivate_cmd} ; .\\display.ps1"
         check_command_output(cmd, prevenv)
 
 
