@@ -1,7 +1,6 @@
 import os
 import platform
 import subprocess
-import unittest
 
 import pytest
 
@@ -27,68 +26,65 @@ class RunnerMock:
         return 0 if self.return_ok else 1
 
 
-class ReplaceInFileTest(unittest.TestCase):
-    def setUp(self):
-        text = u'J\xe2nis\xa7'
-        self.tmp_folder = temp_folder()
+def test_replace_in_file():
+    text = u'J\xe2nis\xa7'
+    tmp_folder = temp_folder()
 
-        self.win_file = os.path.join(self.tmp_folder, "win_encoding.txt")
-        text = text.encode("Windows-1252", "ignore")
-        with open(self.win_file, "wb") as handler:
-            handler.write(text)
+    win_file = os.path.join(tmp_folder, "win_encoding.txt")
+    text = text.encode("Windows-1252", "ignore")
+    with open(win_file, "wb") as handler:
+        handler.write(text)
+    replace_in_file(ConanFileMock(), win_file, "nis", "nus", encoding="Windows-1252")
 
-    def test_replace_in_file(self):
-        replace_in_file(ConanFileMock(), self.win_file, "nis", "nus", encoding="Windows-1252")
-
-        content = load(self.win_file, encoding="Windows-1252")
-        self.assertNotIn("nis", content)
-        self.assertIn("nus", content)
+    content = load(win_file, encoding="Windows-1252")
+    assert "nis" not in  content
+    assert "nus" in content
 
 
-class ToolsTest(unittest.TestCase):
+class TestToolsTest:
 
     def test_load_save(self):
         folder = temp_folder()
         path = os.path.join(folder, "file")
         save(path, u"äüïöñç")
         content = load(path)
-        self.assertEqual(content, u"äüïöñç")
+        assert content == u"äüïöñç"
 
     def test_md5(self):
         result = md5(u"äüïöñç")
-        self.assertEqual("dfcc3d74aa447280a7ecfdb98da55174", result)
+        assert "dfcc3d74aa447280a7ecfdb98da55174" == result
 
     def test_environment_nested(self):
         with environment_update({"A": "1", "Z": "40"}):
             with environment_update({"A": "1", "B": "2"}):
                 with environment_update({"A": "2", "B": "2"}):
-                    self.assertEqual(os.getenv("A"), "2")
-                    self.assertEqual(os.getenv("B"), "2")
-                    self.assertEqual(os.getenv("Z"), "40")
-                self.assertEqual(os.getenv("A", None), "1")
-                self.assertEqual(os.getenv("B", None), "2")
-            self.assertEqual(os.getenv("A", None), "1")
-            self.assertEqual(os.getenv("Z", None), "40")
+                    assert os.getenv("A") == "2"
+                    assert os.getenv("B") == "2"
+                    assert os.getenv("Z") == "40"
+                assert os.getenv("A") == "1"
+                assert os.getenv("B",) == "2"
+            assert os.getenv("A",) == "1"
+            assert os.getenv("Z") == "40"
 
-        self.assertEqual(os.getenv("A", None), None)
-        self.assertEqual(os.getenv("B", None), None)
-        self.assertEqual(os.getenv("Z", None), None)
+        assert os.getenv("A") is None
+        assert os.getenv("B") is None
+        assert os.getenv("Z") is None
 
     def test_check_output_runner(self):
         payload = "hello world"
         output = check_output_runner("echo {}".format(payload), stderr=subprocess.STDOUT)
-        self.assertIn(payload, str(output))
+        assert payload in str(output)
 
 
-class CollectLibTestCase(unittest.TestCase):
+class TestCollectLib:
 
     def test_collect_libs(self):
         output = RedirectedTestOutput()
-        with redirect_output(output):
+        with (redirect_output(output)):
             conanfile = ConanFileMock()
             # Without package_folder
             result = collect_libs(conanfile)
-            self.assertEqual([], result)
+            assert []  == result
 
             # Default behavior
             conanfile.folders.set_base_package(temp_folder())
@@ -96,29 +92,29 @@ class CollectLibTestCase(unittest.TestCase):
             save(mylib_path, "")
             conanfile.cpp = Infos()
             result = collect_libs(conanfile)
-            self.assertEqual(["mylib"], result)
+            assert ["mylib"]  == result
 
             # Custom folder
             customlib_path = os.path.join(conanfile.package_folder, "custom_folder", "customlib.lib")
             save(customlib_path, "")
             result = collect_libs(conanfile, folder="custom_folder")
-            self.assertEqual(["customlib"], result)
+            assert ["customlib"]  == result
 
             # Custom folder doesn't exist
             result = collect_libs(conanfile, folder="fake_folder")
-            self.assertEqual([], result)
-            self.assertIn("Lib folder doesn't exist, can't collect libraries:", output.getvalue())
+            assert []  == result
+            assert "Lib folder doesn't exist, can't collect libraries:" in output.getvalue()
             output.clear()
 
             # Use cpp_info.libdirs
             conanfile.cpp_info.libdirs = ["lib", "custom_folder"]
             result = collect_libs(conanfile)
-            self.assertEqual(["customlib", "mylib"], result)
+            assert ["customlib", "mylib"]  == result
 
             # Custom folder with multiple libdirs should only collect from custom folder
-            self.assertEqual(["lib", "custom_folder"], conanfile.cpp_info.libdirs)
+            assert ["lib", "custom_folder"] == conanfile.cpp_info.libdirs
             result = collect_libs(conanfile, folder="custom_folder")
-            self.assertEqual(["customlib"], result)
+            assert ["customlib"]  == result
 
             # Warn same lib different folders
             conanfile = ConanFileMock()
@@ -132,7 +128,7 @@ class CollectLibTestCase(unittest.TestCase):
 
             output.clear()
             result = collect_libs(conanfile)
-            self.assertEqual(["mylib"], result)
+            assert ["mylib"]  == result
 
             # Warn lib folder does not exist with correct result
             conanfile = ConanFileMock()
@@ -144,9 +140,9 @@ class CollectLibTestCase(unittest.TestCase):
             conanfile.cpp_info.libdirs = ["no_folder", "lib"]  # 'no_folder' does NOT exist
             output.clear()
             result = collect_libs(conanfile)
-            self.assertEqual(["mylib"], result)
-            self.assertIn("WARN: Lib folder doesn't exist, can't collect libraries: %s"
-                          % no_folder_path, output.getvalue())
+            assert ["mylib"]  == result
+            assert ("WARN: Lib folder doesn't exist, "
+                    "can't collect libraries: %s") % no_folder_path in output.getvalue()
 
     @pytest.mark.skipif(platform.system() == "Windows", reason="Needs symlinks support")
     def test_collect_libs_symlinks(self):
@@ -166,7 +162,7 @@ class CollectLibTestCase(unittest.TestCase):
         save(lib_mylib3_path, "")
         conanfile.cpp_info.libdirs = ["lib", "custom_folder"]
         result = collect_libs(conanfile)
-        self.assertEqual(["mylib", "mylib.2", "mylib.3"], result)
+        assert ["mylib", "mylib.2", "mylib.3"]  == result
 
     def test_self_collect_libs(self):
         output = RedirectedTestOutput()
@@ -174,7 +170,7 @@ class CollectLibTestCase(unittest.TestCase):
             conanfile = ConanFileMock()
             # Without package_folder
             result = collect_libs(conanfile)
-            self.assertEqual([], result)
+            assert []  == result
 
             # Default behavior
             conanfile.folders.set_base_package(temp_folder())
@@ -182,29 +178,29 @@ class CollectLibTestCase(unittest.TestCase):
             save(mylib_path, "")
             conanfile.cpp = Infos()
             result = collect_libs(conanfile)
-            self.assertEqual(["mylib"], result)
+            assert ["mylib"]  == result
 
             # Custom folder
             customlib_path = os.path.join(conanfile.package_folder, "custom_folder", "customlib.lib")
             save(customlib_path, "")
             result = collect_libs(conanfile, folder="custom_folder")
-            self.assertEqual(["customlib"], result)
+            assert ["customlib"]  == result
 
             # Custom folder doesn't exist
             output.clear()
             result = collect_libs(conanfile, folder="fake_folder")
-            self.assertEqual([], result)
-            self.assertIn("Lib folder doesn't exist, can't collect libraries:", output.getvalue())
+            assert []  == result
+            assert "Lib folder doesn't exist, can't collect libraries:" in output.getvalue()
 
             # Use cpp_info.libdirs
             conanfile.cpp_info.libdirs = ["lib", "custom_folder"]
             result = collect_libs(conanfile)
-            self.assertEqual(["customlib", "mylib"], result)
+            assert ["customlib", "mylib"]  == result
 
             # Custom folder with multiple libdirs should only collect from custom folder
-            self.assertEqual(["lib", "custom_folder"], conanfile.cpp_info.libdirs)
+            assert ["lib", "custom_folder"] == conanfile.cpp_info.libdirs
             result = collect_libs(conanfile, folder="custom_folder")
-            self.assertEqual(["customlib"], result)
+            assert ["customlib"]  == result
 
             # Warn same lib different folders
             conanfile = ConanFileMock()
@@ -217,7 +213,7 @@ class CollectLibTestCase(unittest.TestCase):
             conanfile.cpp_info.libdirs = ["lib", "custom_folder"]
             output.clear()
             result = collect_libs(conanfile)
-            self.assertEqual(["mylib"], result)
+            assert ["mylib"]  == result
 
             # Warn lib folder does not exist with correct result
             conanfile = ConanFileMock()
@@ -229,9 +225,9 @@ class CollectLibTestCase(unittest.TestCase):
             conanfile.cpp_info.libdirs = ["no_folder", "lib"]  # 'no_folder' does NOT exist
             output.clear()
             result = collect_libs(conanfile)
-            self.assertEqual(["mylib"], result)
-            self.assertIn("WARN: Lib folder doesn't exist, can't collect libraries: %s"
-                          % no_folder_path, output.getvalue())
+            assert ["mylib"]  == result
+            assert ("WARN: Lib folder doesn't exist, "
+                    "can't collect libraries: %s" % no_folder_path in output.getvalue())
 
     @pytest.mark.skipif(platform.system() == "Windows", reason="Needs symlinks support")
     def test_self_collect_libs_symlinks(self):
@@ -251,4 +247,4 @@ class CollectLibTestCase(unittest.TestCase):
         save(lib_mylib3_path, "")
         conanfile.cpp_info.libdirs = ["lib", "custom_folder"]
         result = collect_libs(conanfile)
-        self.assertEqual(["mylib", "mylib.2", "mylib.3"], result)
+        assert ["mylib", "mylib.2", "mylib.3"]  == result
